#ifndef _LIBIDN_LIB_IDN_INT_H
#define _LIBIDN_LIB_IDN_INT_H 1
#ifndef _GENERATED_STDINT_H
#define _GENERATED_STDINT_H "libidn 0.6.5"
/* generated using gnu compiler s390x-slackware-linux-gcc (GCC) 3.4.6 */
#define _STDINT_HAVE_STDINT_H 1
#include <stdint.h>
#endif
#endif
